@@ -42,7 +42,7 @@ class AbstractGeneratorXml(object):
 
     @property
     def cadena_original(self):
-        return self.cadena_original
+        return self.__cadena_original
 
     @abstractmethod
     def generate_xml(self):
